@@ -2,8 +2,18 @@
 #' @description Load a crontab from file
 #' @param file The file location of a crontab.
 #' @param user The user for whom we will be loading a crontab.
+#' @param ask Boolean; show prompt asking for validation
 #' @export
-cron_load <- function(file, user="") {
+cron_load <- function(file, user="", ask=TRUE) {
+  stopifnot(is.character(file) && file.exists(file))
+  if(ask){
+    cat(sep="", "Are you sure you want to load the cron jobs available at '", file, "'? [y/n]: ")
+    input <- tolower(scan(what=character(), n=1, quiet=TRUE))
+    if (!input %in% "y") {
+      message("No action taken.")
+      return(invisible())
+    }
+  }
   if (user == "") {
     system(paste("crontab", file))
   } else {
